@@ -302,12 +302,11 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
     # ensure yarn installs all build tools
         local("pwd")
-        local('YARN_CACHE_FOLDER=%s yarn --production=false --no-progress --non-interactive install' % yarn_cache)
-
+        local('yarn --production=false --no-progress --non-interactive install --cache-folder %s' % yarn_cache)
  
         if ngBuild:
             options = ' --configuration=%s ' % angularEnv if angularEnv else ''
-            local('YARN_CACHE_FOLDER=%s yarn build %s %s' % (yarne_cache, options, ngApp))
+            local('yarn build %s %s' % (options, ngApp))
             local('cp {package.json,yarn.lock,knexfile.js} dist/')
             local('cp -R migrations/ dist/migrations')
             local('if [ -d "apps/%s/config" ]; then cp -R "apps/%s/config" "dist/apps/%s/"; fi' % (ngApp,ngApp,ngApp))
@@ -321,6 +320,7 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
             local('if [[ -d "config" ]]; then echo "<collecting config>" ; rsync -ra --stats config/ dist/config; fi;')
             local('if [[ -d "src/public" ]]; then echo "<collecting public>" ; rsync -ra --stats src/public/ dist/public; fi;')
 
+        local('du -h %s' % yarn_cache)
 
     # make sure the new files are part of the local git repo
     #local('find . -path ./\.git -prune -o -name \.gitignore -type f -exec rm -f {} \;')
